@@ -19,11 +19,15 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 */
 // Self
-#include "resizeimagedialog.moc"
+#include "resizeimagedialog.h"
 
 // Qt
+#include <QDialogButtonBox>
+#include <QPushButton>
 
 // KDE
+#include <KLocalizedString>
+#include <KGuiItem>
 
 // Local
 #include <ui_resizeimagewidget.h>
@@ -38,23 +42,32 @@ struct ResizeImageDialogPrivate : public Ui_ResizeImageWidget
 };
 
 ResizeImageDialog::ResizeImageDialog(QWidget* parent)
-: KDialog(parent)
+: QDialog(parent)
 , d(new ResizeImageDialogPrivate)
 {
     d->mUpdateFromRatio = false;
 
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    setLayout(mainLayout);
     QWidget* content = new QWidget(this);
     d->setupUi(content);
+    mainLayout->addWidget(content);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
+    QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
+    okButton->setDefault(true);
+    okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+    connect(buttonBox, &QDialogButtonBox::accepted, this, &ResizeImageDialog::accept);
+    connect(buttonBox, &QDialogButtonBox::rejected, this, &ResizeImageDialog::reject);
+    mainLayout->addWidget(buttonBox);
+
     content->layout()->setMargin(0);
-    setMainWidget(content);
-    showButtonSeparator(true);
-    setButtonGuiItem(Ok, KGuiItem(i18n("Resize"), "transform-scale"));
+    KGuiItem::assign(okButton, KGuiItem(i18n("Resize"), "transform-scale"));
     setWindowTitle(content->windowTitle());
     d->mWidthSpinBox->setFocus();
 
-    connect(d->mWidthSpinBox, SIGNAL(valueChanged(int)), SLOT(slotWidthChanged(int)));
-    connect(d->mHeightSpinBox, SIGNAL(valueChanged(int)), SLOT(slotHeightChanged(int)));
-    connect(d->mKeepAspectCheckBox, SIGNAL(toggled(bool)), SLOT(slotKeepAspectChanged(bool)));
+    connect(d->mWidthSpinBox, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &ResizeImageDialog::slotWidthChanged);
+    connect(d->mHeightSpinBox, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &ResizeImageDialog::slotHeightChanged);
+    connect(d->mKeepAspectCheckBox, &QCheckBox::toggled, this, &ResizeImageDialog::slotKeepAspectChanged);
 }
 
 ResizeImageDialog::~ResizeImageDialog()
